import prisma from '../utilities/prisma' // Import the global Prisma instance

class PasswordResetTokenRepository {
  async getById(id: number): Promise<any> {
    try {
      return await prisma.passwordResetToken.findUnique({
        where: {
          id
        }
      })
    } catch (error: any) {
      // Handle error
      throw new Error(`Failed to get password reset token by ID: ${error.message}`)
    }
  }

  async getByUserId(userId: number): Promise<any> {
    try {
      return await prisma.passwordResetToken.findFirst({
        where: {
          userId
        }
      })
    } catch (error: any) {
      // Handle error
      throw new Error(`Failed to get password reset token by user ID: ${error.message}`)
    }
  }

  async getByToken(token: string): Promise<any> {
    try {
      return await prisma.passwordResetToken.findFirst({
        where: {
          token
        }
      })
    } catch (error: any) {
      // Handle error
      throw new Error(`Failed to get password reset token by token: ${error.message}`)
    }
  }
}

export default new PasswordResetTokenRepository()
